==> tine20-allinone_2019.12.5.tar.bz2: Timetracker/js/Timetracker-lang-cs-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Czech (http://www.transifex.com/tine20/tine20/language/cs/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: cs\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Timesheet, Timesheets"
: [
  "Pracovní výkaz"
 ,"Pracovní výkazy"
 ,"Pracovních výkazů"
 ,"Pracovních výkazů"

]
, "Account"
: "Účet"

, "Time Account (Number - Title)"
: ""

, "Billable"
: "Lze účtovat"

, "Cleared in"
: "Zaplaceno v"

, "Invoice"
: ""

, "Cleared"
: "Zaplaceno"

, "Date"
: "Datum"

, "Start time"
: "Počáteční čas"

, "End time"
: ""

, "Duration"
: "Trvání"

, "Description"
: "Popis"

, "Type"
: ""

, "Time Account closed"
: "Časový fond uzavřen"

, "hour"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""
 ,""
 ,""

]
, "Contract"
: ""

, "Title"
: "Název"

, "Number"
: "Číslo"

, "Price"
: ""

, "Status"
: "Stav"

, "Billed"
: "Účtovaný"

, "Cleared at"
: ""

, "Booking deadline"
: "Nejzazší termín rezervace"

, "Responsible"
: ""

, "Cost Center"
: ""

, "Responsible Person"
: ""

, "Time Account, Time Accounts"
: [
  "Časový fond"
 ,"Časové fondy"
 ,"Časových fondů"
 ,"Časových fondů"

]
, "Time Account - Status"
: "Stav časového fondu"

, "closed"
: "uzavřený"

, "open"
: "otevřený"

, "Not a valid time"
: "Neplatný čas"

, "Time Account - Billed"
: ""

, "not yet billed"
: "zatím neúčtovaný"

, "to bill"
: "k účtování"

, "billed"
: "účtovaný"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""
 ,""
 ,""

]
, "Favorite"
: ""

, "Cleared In"
: "Zaplaceno v"

, "Select Time Account..."
: "Vyberte časový fond..."

, "Start"
: "Začátek"

, "not set"
: "není nastaveno"

, "End"
: ""

, "Enter description..."
: "Zadejte popis..."

, "Need for Clarification"
: ""

, "Failed"
: "Nezdařilo se"

, "Could not save {0}."
: "Nepodařilo se uložit {0}."

, "Booking deadline for this Timeaccount has been exceeded."
: "Nejzazší termín rezervace tohoto časového fondu byl překročen."

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""
 ,""
 ,""

]
, "Book Own"
: "Zakládat vlastní"

, "The grant to add Timesheets to this Timeaccount"
: "Oprávnění přidávat pracovní výkazy k tomuto časovému fondu"

, "View All"
: "Prohlížet vše"

, "The grant to view Timesheets of other users"
: "Oprávnění prohlížet pracovní výkazy ostatních uživatelů"

, "Book All"
: "Zakládat vše"

, "The grant to add Timesheets for other users"
: "Oprávnění přidávat pracovní výkazy ostatním uživatelům"

, "Manage Clearing"
: "Spravovat platby"

, "The grant to manage clearing of Timesheets"
: "Oprávnění spravovat vyúčtování pracovních výkazů"

, "without contract"
: ""

, "without responsible"
: ""

, "timeframe"
: "časový rámec"

, "summary"
: "přehled"

, "Total Timesheets"
: "Celkem výkazů"

, "Billable Timesheets"
: "Účtovatelných výkazů"

, "Total Time"
: "Celkový čas"

, "Time of Billable Timesheets"
: "Čas účtovatelných výkazů"

, "Detail"
: "Detail"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: ""

, "Export as ODS"
: "Exportovat do ODS"

, "Export as CSV"
: "Exportovat do CSV"

, "Export as ..."
: ""

, "Add New Timeaccount"
: ""

, "Unit"
: "Jednotka"

, "Unit Price"
: "Jednotková cena"

, "Budget"
: "Rozpočet"

, "Timesheets are billable"
: "Pracovní výkazy lze účtovat"

, "Access"
: "Přístup"

, "Permissions"
: "Oprávnění"

, "Show closed"
: "Zobrazit uzavřené"

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "Timesheets ODS export configuration"
: "Konfigurace exportu pracovních výkazů do ODS"

, "Use this configuration for the timesheet ODS export."
: "Použít tuto konfiguraci pro export pracovních výkazů do ODS."

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "výchozí"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "Working time"
: ""

, "Project time"
: ""

, "none"
: "žádný"

, "last week"
: "minulý týden"

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Manage timeaccounts"
: "Spravovat časové fondy"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: ""

, "Add timeaccounts"
: ""

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: ""

, "Create or update shared timesheet favorites"
: ""

, "My Timesheets today"
: ""

, "My Timesheets this week"
: ""

, "My Timesheets last week"
: ""

, "My Timesheets this month"
: ""

, "My Timesheets last month"
: ""

, "Timeaccounts to bill"
: ""

, "Timeaccounts not yet billed"
: ""

, "Timeaccounts already billed"
: ""

, "Timetracker"
: "Sledování času"

, "Timesheet"
: "Pracovní výkaz"

, "Timeaccount"
: ""

, "Time Account"
: "Časový fond"

, "Delete {0}"
: ""

, "Timeaccount Grant"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Timetracker/js/Timetracker-lang-cs-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Czech (http://www.transifex.com/tine20/tine20/language/cs/)\nLanguage: cs\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "časový rámec"

, "summary"
: "přehled"

, "Total Timesheets"
: "Celkem výkazů"

, "Billable Timesheets"
: "Účtovatelných výkazů"

, "Total Time"
: "Celkový čas"

, "Time of Billable Timesheets"
: "Čas účtovatelných výkazů"

, "Description"
: "Popis"

, "Detail"
: "Detail"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: ""

, "Export as ODS"
: "Exportovat do ODS"

, "Export as CSV"
: "Exportovat do CSV"

, "Export as ..."
: ""

, "Timesheet, Timesheets"
: [
  "Pracovní výkaz"
 ,"Pracovní výkazy"
 ,"Pracovních výkazů"
 ,"Pracovních výkazů"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""
 ,""
 ,""

]
, "Failed"
: "Nezdařilo se"

, "Could not save {0}."
: "Nepodařilo se uložit {0}."

, "Booking deadline for this Timeaccount has been exceeded."
: "Nejzazší termín rezervace tohoto časového fondu byl překročen."

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: ""

, "without contract"
: ""

, "Add New Timeaccount"
: ""

, "Unit"
: "Jednotka"

, "Unit Price"
: "Jednotková cena"

, "Factor"
: ""

, "Budget"
: "Rozpočet"

, "Status"
: "Stav"

, "closed"
: "uzavřený"

, "open"
: "otevřený"

, "Cleared In"
: "Zaplaceno v"

, "Cleared at"
: ""

, "Cost Center"
: ""

, "Responsible Person"
: ""

, "Timesheets are billable"
: "Pracovní výkazy lze účtovat"

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  "Časový fond"
 ,"Časové fondy"
 ,"Časových fondů"
 ,"Časových fondů"

]
, "Number"
: "Číslo"

, "Title"
: "Název"

, "Access"
: "Přístup"

, "Permissions"
: "Oprávnění"

, "Time Account - Billed"
: ""

, "not yet billed"
: "zatím neúčtovaný"

, "to bill"
: "k účtování"

, "billed"
: "účtovaný"

, "Time Account - Status"
: "Stav časového fondu"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""
 ,""
 ,""

]
, "Book Own"
: "Zakládat vlastní"

, "The grant to add Timesheets to this Timeaccount"
: "Oprávnění přidávat pracovní výkazy k tomuto časovému fondu"

, "View All"
: "Prohlížet vše"

, "The grant to view Timesheets of other users"
: "Oprávnění prohlížet pracovní výkazy ostatních uživatelů"

, "Book All"
: "Zakládat vše"

, "The grant to add Timesheets for other users"
: "Oprávnění přidávat pracovní výkazy ostatním uživatelům"

, "Manage Clearing"
: "Spravovat platby"

, "The grant to manage clearing of Timesheets"
: "Oprávnění spravovat vyúčtování pracovních výkazů"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""
 ,""
 ,""

]
, "Favorite"
: ""

, "Show closed"
: "Zobrazit uzavřené"

, "Timesheets ODS export configuration"
: "Konfigurace exportu pracovních výkazů do ODS"

, "Use this configuration for the timesheet ODS export."
: "Použít tuto konfiguraci pro export pracovních výkazů do ODS."

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "výchozí"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: "žádný"

, "last week"
: "minulý týden"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: "Zaplaceno v"

, "Billed"
: "Účtovaný"

, "Booking deadline"
: "Nejzazší termín rezervace"

, "Accounting time factor"
: ""

, "hour"
: ""

, "Account"
: "Účet"

, "Time Account (Number - Title)"
: ""

, "Billable"
: "Lze účtovat"

, "Cleared"
: "Zaplaceno"

, "Date"
: "Datum"

, "Start time"
: "Počáteční čas"

, "End time"
: ""

, "Duration"
: "Trvání"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Time Account closed"
: "Časový fond uzavřen"

, "Timetracker"
: "Sledování času"

, "Timeaccounts to bill"
: ""

, "Timeaccounts not yet billed"
: ""

, "Timeaccounts already billed"
: ""

, "My Timesheets today"
: ""

, "My Timesheets this week"
: ""

, "My Timesheets last week"
: ""

, "My Timesheets this month"
: ""

, "My Timesheets last month"
: ""

, "Manage timeaccounts"
: "Spravovat časové fondy"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: ""

, "Add timeaccounts"
: ""

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: ""

, "Create or update shared timesheet favorites"
: ""






, "Timesheet"
: "Pracovní výkaz"

, "Timeaccount"
: ""

, "Time Account"
: "Časový fond"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
